@@ -14,11 +14,10 @@ import logging
 import os
 import re
 import sys
-import pandas as pd
-
 from csv import DictWriter
 from decimal import Decimal
 
+import pandas as pd
 from scipy.sparse import issparse
 from sklearn.feature_extraction import FeatureHasher
 
@@ -32,7 +31,7 @@ class Writer(object):
     path : str
         A path to the feature file we would like to create. The suffix
         to this filename must be ``.arff``, ``.csv``, ``.jsonlines``,
-        ``.libsvm``, ``.megam``, ``.ndj``, or ``.tsv``. If ``subsets``
+        ``.libsvm``, ``.ndj``, or ``.tsv``. If ``subsets``
         is not ``None``, when calling the ``write()`` method, path is
         assumed to be a string containing the path to the directory to
         write the feature files with an additional file extension
@@ -77,8 +76,8 @@ class Writer(object):
         self._progress_msg = ''
         self._use_pandas = False
         if kwargs:
-            raise ValueError('Passed extra keyword arguments to '
-                             'Writer constructor: {}'.format(kwargs))
+            raise ValueError('Passed extra keyword arguments to Writer '
+                             f'constructor: {kwargs}')
 
     @classmethod
     def for_path(cls, path, feature_set, **kwargs):
@@ -91,7 +90,7 @@ class Writer(object):
         path : str
             A path to the feature file we would like to create. The
             suffix to this filename must be ``.arff``, ``.csv``,
-            ``.jsonlines``, ``.libsvm``, ``.megam``, ``.ndj``, or
+            ``.jsonlines``, ``.libsvm``, ``.ndj``, or
             ``.tsv``. If ``subsets`` is not ``None``, when calling the
             ``write()`` method, path is assumed to be a string
             containing the path to the directory to write the feature
@@ -110,7 +109,7 @@ class Writer(object):
             appropriate for the given path.
         """
         # Get lowercase extension for file extension checking
-        ext = '.' + path.rsplit('.', 1)[-1].lower()
+        ext = f'.{path.rsplit(".", 1)[-1].lower()}'
         return EXT_TO_WRITER[ext](path, feature_set, **kwargs)
 
     def write(self):
@@ -129,10 +128,9 @@ class Writer(object):
         # Otherwise write one feature file per subset
         else:
             for subset_name, filter_features in self.subsets.items():
-                self.logger.debug('Subset ({}) features: {}'.format(subset_name,
-                                                                    filter_features))
-                sub_path = os.path.join(self.root, '{}{}'.format(subset_name,
-                                                                 self.ext))
+                self.logger.debug(f'Subset ({subset_name}) features: '
+                                  f'{filter_features}')
+                sub_path = os.path.join(self.root, f'{subset_name}{self.ext}')
                 self._write_subset(sub_path, set(filter_features))
 
     def _write_subset(self, sub_path, filter_features):
@@ -147,12 +145,12 @@ class Writer(object):
         filter_features : set of str
             Set of features to include in current feature file.
         """
-        self.logger.debug('sub_path: %s', sub_path)
-        self.logger.debug('feature_set: %s', self.feat_set.name)
-        self.logger.debug('filter_features: %s', filter_features)
+        self.logger.debug(f'sub_path: {sub_path}')
+        self.logger.debug(f'feature_set: {self.feat_set.name}')
+        self.logger.debug(f'filter_features: {filter_features}')
 
         if not self.quiet:
-            self._progress_msg = "Writing {}...".format(sub_path)
+            self._progress_msg = f"Writing {sub_path}..."
             print(self._progress_msg, end="\r", file=sys.stderr)
             sys.stderr.flush()
 
@@ -170,15 +168,14 @@ class Writer(object):
                 for ex_num, (id_, label_, feat_dict) in enumerate(filtered_set):
                     self._write_line(id_, label_, feat_dict, output_file)
                     if not self.quiet and ex_num % 100 == 0:
-                        print("{}{:>15}".format(self._progress_msg, ex_num),
+                        print(f"{self._progress_msg}{ex_num:>15}",
                               end="\r", file=sys.stderr)
                         sys.stderr.flush()
         else:
             self._write_data(self.feat_set, sub_path, filter_features)
 
         if not self.quiet:
-            print("{}{:<15}".format(self._progress_msg, "done"),
-                  file=sys.stderr)
+            print(f"{self._progress_msg}{'done':<15}", file=sys.stderr)
             sys.stderr.flush()
 
     def _write_header(self, feature_set, output_file, filter_features):
@@ -369,16 +366,16 @@ class Writer(object):
         # if the id column is already in the data frame,
         # then raise an error; otherwise, just add the ids
         if self.id_col in df_features:
-            raise ValueError('ID column name "{}" already used as feature '
-                             'name.'.format(self.id_col))
+            raise ValueError(f'ID column name "{self.id_col}" already used as'
+                             ' feature name.')
         df_features[self.id_col] = feature_set.ids
 
         # if the the labels should exist but the column is already
         # in the data frame, then raise an error; otherwise, just add the labels
         if feature_set.has_labels:
             if self.label_col in df_features:
-                raise ValueError(('Class column name "{}" already used as '
-                                  'feature name.').format(self.label_col))
+                raise ValueError(f'Class column name "{self.label_col}" '
+                                 'already used as feature name.')
             df_features[self.label_col] = feature_set.labels
 
         return df_features
@@ -412,7 +409,7 @@ class CSVWriter(Writer):
         self.id_col = kwargs.pop('id_col', 'id')
         super(CSVWriter, self).__init__(path, feature_set, **kwargs)
         self._pandas_kwargs = {} if pandas_kwargs is None else pandas_kwargs
-        self._sep = self._pandas_kwargs.pop('sep', str(','))
+        self._sep = self._pandas_kwargs.pop('sep', ',')
         self._index = self._pandas_kwargs.pop('index', False)
         self._use_pandas = True
 
@@ -518,24 +515,24 @@ class ARFFWriter(Writer):
         fieldnames.append(self.id_col)
 
         # Add relation to header
-        print("@relation '{}'\n".format(self.relation), file=output_file)
+        print(f"@relation '{self.relation}'\n", file=output_file)
 
         # Loop through fields writing the header info for the ARFF file
         for field in fieldnames:
-            print("@attribute '{}' numeric".format(field.replace('\\', '\\\\')
-                                                   .replace("'", "\\'")),
-                  file=output_file)
+            field = field.replace('\\', '\\\\').replace("'", "\\'")
+            print(f"@attribute '{field}' numeric", file=output_file)
 
         # Print class label header if necessary
         if self.regression:
-            print("@attribute {} numeric".format(self.label_col),
-                  file=output_file)
+            print(f"@attribute {self.label_col} numeric", file=output_file)
         else:
             if self.feat_set.has_labels:
-                print("@attribute {} ".format(self.label_col) +
-                      "{" + ','.join(list(map(str,
-                                              sorted(set(self.feat_set.labels))))) +
-                      "}", file=output_file)
+                labels_str = ','.join(
+                    list(map(str, sorted(set(self.feat_set.labels))))
+                )
+                labels_str = "{" + labels_str + "}"
+                print(f"@attribute {self.label_col} {labels_str}",
+                      file=output_file)
         if self.label_col:
             fieldnames.append(self.label_col)
 
@@ -574,72 +571,18 @@ class ARFFWriter(Writer):
             if self.feat_set.has_labels:
                 feat_dict[self.label_col] = label_
         else:
-            raise ValueError(('Class column name "{}" already used as feature '
-                              'name.').format(self.label_col))
+            raise ValueError(f'Class column name "{self.label_col}" already '
+                             'used as feature name.')
         # Add id column to feat_dict if id is provided
         if self.id_col not in feat_dict:
             feat_dict[self.id_col] = id_
         else:
-            raise ValueError('ID column name "{}" already used as feature '
-                             'name.'.format(self.id_col))
+            raise ValueError(f'ID column name "{self.id_col}" already used as'
+                             ' feature name.')
         # Write out line
         self._dict_writer.writerow(feat_dict)
 
 
-class MegaMWriter(Writer):
-
-    """
-    Writer for writing out FeatureSets as MegaM files.
-    """
-
-    @staticmethod
-    def _replace_non_ascii(line):
-        """
-        Parameters
-        ----------
-        line : str
-            The line to clean up.
-
-        Returns
-        -------
-        char_list : str
-            Copy of line with all non-ASCII characters replaced with
-            <U1234> sequences where 1234 is the value of ord() for the character.
-        """
-        char_list = []
-        for char in line:
-            char_num = ord(char)
-            char_list.append(
-                '<U{}>'.format(char_num) if char_num > 127 else char)
-        return ''.join(char_list)
-
-    def _write_line(self, id_, label_, feat_dict, output_file):
-        """
-        Write the current line in the file in MegaM format.
-
-        Parameters
-        ----------
-        id_ : str
-            The ID for the current instance.
-        label_ : str
-            The label for the current instance.
-        feat_dict : dict
-            The feature dictionary for the current instance.
-        output_file : file buffer
-            The file being written to.
-        """
-        # Don't try to add class column if this is label-less data
-        print('# {}'.format(id_), file=output_file)
-        if self.feat_set.has_labels:
-            print('{}'.format(label_), end='\t', file=output_file)
-        print(self._replace_non_ascii(' '.join(('{} {}'.format(field,
-                                                               value) for
-                                                field, value in
-                                                sorted(feat_dict.items()) if
-                                                Decimal(value) != 0))),
-              file=output_file)
-
-
 class NDJWriter(Writer):
 
     """
@@ -755,6 +698,7 @@ class LibSVMWriter(Writer):
         name : str
             The class names with unicode equivalent replacements.
         """
+
         if isinstance(name, str):
             for orig, replacement in LibSVMWriter.LIBSVM_REPLACE_DICT.items():
                 name = name.replace(orig, replacement)
@@ -762,7 +706,7 @@ class LibSVMWriter(Writer):
 
     def _write_line(self, id_, label_, feat_dict, output_file):
         """
-        Write the current line in the file in MegaM format.
+        Write the current line in the file in this Writer's format.
 
         Parameters
         ----------
@@ -775,34 +719,34 @@ class LibSVMWriter(Writer):
         output_file : file buffer
             The file being written to.
         """
+
         field_values = sorted([(self.feat_set.vectorizer.vocabulary_[field] +
                                 1, value) for field, value in
                                feat_dict.items() if Decimal(value) != 0])
         # Print label
         if label_ in self.label_map:
-            print('{}'.format(self.label_map[label_]), end=' ',
-                  file=output_file)
+            print(self.label_map[label_], end=' ', file=output_file)
         else:
-            print('{}'.format(label_), end=' ', file=output_file)
+            print(label_, end=' ', file=output_file)
         # Print features
-        print(' '.join(('{}:{}'.format(field, value) for field, value in
-                        field_values)), end=' ', file=output_file)
+        print(' '.join((f'{field}:{value}' for field, value in field_values)),
+              end=' ', file=output_file)
         # Print comment with id and mappings
         print('#', end=' ', file=output_file)
-        print(self._sanitize('{}'.format(id_)), end='',
-              file=output_file)
+        print(self._sanitize(id_), end='', file=output_file)
         print(' |', end=' ', file=output_file)
 
         if label_ in self.label_map:
-            print('%s=%s' % (self._sanitize(self.label_map[label_]),
-                             self._sanitize(label_)),
+            print(f'{self._sanitize(self.label_map[label_])}='
+                  f'{self._sanitize(label_)}',
                   end=' | ', file=output_file)
         else:
             print(' |', end=' ', file=output_file)
-        line = ' '.join(('%s=%s' % (self.feat_set.vectorizer.vocabulary_[field] + 1,
-                                    self._sanitize(field))
-                         for field, value in feat_dict.items()
-                         if Decimal(value) != 0))
+        line = ' '.join(
+            f'{self.feat_set.vectorizer.vocabulary_[field] + 1}='
+            f'{self._sanitize(field)}'
+            for field, value in feat_dict.items() if Decimal(value) != 0
+        )
         print(line, file=output_file)
 
 
@@ -811,6 +755,5 @@ EXT_TO_WRITER = {".arff": ARFFWriter,
                  ".csv": CSVWriter,
                  ".jsonlines": NDJWriter,
                  ".libsvm": LibSVMWriter,
-                 ".megam": MegaMWriter,
                  '.ndj': NDJWriter,
                  ".tsv": TSVWriter}
